/*Based on https://github.com/samirelanduk/reddit-save/blob/master/html/style.css */

* {
    color: white;
    -webkit-appearance: none;
    -moz-appearance: none;
    image-rendering: -webkit-optimize-contrast;
}

.saved *{
    color: green;
}

.recovered *{
    color: coral;
}

.footer {
    text-align: center;
    padding: 50;
    font-size: 25;
}

.nextPage, .previousPage {
    padding: 10
}

body {
    font-family: 'Open Sans', Verdana;
    background-color: rgb(35, 35, 35);
}

.links {
    padding-bottom: 10;
}

img, video {
    max-height: 500px;
    cursor: pointer;
    max-width: 100%;
}

a {
    color: #0079d3;
    text-decoration: none;
}

time, .subreddit, .user{
    padding-right: 15;
}

p, li {
    font-size: 14px;
    margin-bottom: 8px;
}

ul li {
    list-style: disc;
}

ol li {
    list-style-type: decimal;
}

li {
    margin-left: 24px;
}

em {
    font-style: italic;
}

strong {
    font-weight: bold;
}

code {
    font-family: monospace;
    white-space: pre;
}

blockquote {
    font-style: italic;
    padding-left: 8px;
    position: relative;
}

blockquote:before {
    position: absolute;
    left: 0;
    width: 4px;
    content: "";
    height: 100%;
    background-color: #16a085;
}

a:hover {
    text-decoration: underline;
}

h1 {
    font-weight: bold;
    font-size: 24px;
    padding: 8px 16px;
}

.post, .comment, .reply {
	padding: 12px 16px;
	text-align: left;
}

.replies{
	min-height: unset;
}

.reply {
	min-height: max-content;
}

.comment {
	min-height: unset;
}

.post h2 {
    font-weight: bold;
    font-size: 18px;
}

.post h1, .comment h1 {
    padding: 0;
    margin-bottom: 8px;
    margin-top: 8px;
}

.post .info {
    font-size: 12px;
    font-weight: 300;
    margin-bottom: 16px;
}

.post .info time {
    font-weight: 500;
}

.post .info time, .post .info span {
    padding-right: 10px;
}

.post .links a {
    padding-right: 4px;
    font-weight: 400;
    padding-left: 4px;
}

.post .links a:after {
    position: relative;
    right: -4px;
}

.post .links a:last-child:after {
    content: "";
}

.comment .info {
    display: flex;
    align-items: baseline;
    margin-bottom: 8px;
}

.comment .info time {
    padding-right: 12px;
}

.comment .info div {
    font-weight: bold;
    font-size: 12px;
    padding-right: 8px;
    top: -1px;
}

.comments h2 {
    font-weight: bold;
    font-size: 20px;
    padding: 8px 16px;
}

.op {
    background: #0055df;
    color: white;
    font-weight: 700;
    padding: 0px 4px;
    border-radius: 4px;
}

button {
    border: 1px solid #1abc9c60;
    color: #1abc9c;
    border-radius: 5px;
    padding: 4px 8px;;
    font-size: 12px;
    cursor: pointer;
    position: absolute;
    right: 16px;
    font-weight: bold;
    top: 10px;
    background-color: #1abc9c20;
}

button:hover {
    background-color: #1abc9c40;
}

.row {
  display: -ms-flexbox; /* IE10 */
  display: flex;
  -ms-flex-wrap: wrap; /* IE10 */
  flex-wrap: wrap;
  padding: 0 4px;
}

/* Create four equal columns that sits next to each other */
.column {
  -ms-flex: 25%; /* IE10 */
  flex: 25%;
  max-width: 25%;
  padding: 0 4px;
}

.column img {
  margin-top: 8px;
  vertical-align: middle;
}

/* Responsive layout - makes a two column-layout instead of four columns */
@media screen and (max-width: 800px) {
  .column {
    -ms-flex: 50%;
    flex: 50%;
    max-width: 50%;
  }
}

/* Responsive layout - makes the two columns stack on top of each other instead of next to each other */
@media screen and (max-width: 600px) {
  .column {
    -ms-flex: 100%;
    flex: 100%;
    max-width: 100%;
  }
}

/* Attempt to make collapse-able comments without js lol*/
input[type='checkbox'] {
    display: none;
  }
  
.lbl-toggle {
    display: flex;

}

.collapsible-content {
    max-height: 0px;
    overflow: hidden;
}

.toggle:checked + .lbl-toggle + .collapsible-content {
    max-height: 100%;
}

.lbl-toggle::before {
    font-size: 12px;
    font-weight: bold;
    display: inline-block;
    content: '[+]';
    vertical-align: middle;
    white-space: nowrap;
}

.toggle:checked + .lbl-toggle::before {
    font-size: 12px;
    font-weight: bold;
    display: inline-block;
    content: '[-]';
    white-space: nowrap;
  }

.info div{
    padding-left: 0px;
}

.comment, .reply {
    border-left: 1px solid white;
}

.content {
    padding-bottom: 8px;
    padding-left: 4px;
}

.icon{
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    font-size: 30px;
}

.light_container {
    position: relative;
    width: max-content;
}

.post {
    border: gray solid 1px;
    margin-top: 10px;
}

.old_post{
    margin-top: 8px;
    display: flex;
    flex-direction: row;
    margin-bottom: 8px;  
    padding-top: 8px;  
    padding-bottom: 8px;    
}
.old_post .content .light_container{
    width: 70px;
    height: 70px;    
    text-align: right;
}
.old_post .content .light_container img{
    max-width: 70px;
    max-height: 70px;    
}

.old_post .info .title h1{
    margin:0;
    font-size: 12pt;
    padding: 0;
    font-weight: unset;
  }

.old_post .info {
    display: flex;
    flex-direction: column;
    font-size: 10pt;
}

.old_post .info div{
    padding: 2px;
}
.old_post .content {
    display: relative;
    padding-bottom: 8px;
    padding-left: 4px;
    width: 70px;
    margin-right: 20px;
}

.old_post time, .subreddit, .user {
    padding-right: 0;
}

.old_post .icon{
    font-size: 45px;
    top:43%;
}

.pinned {
    background-color: #16a085;
}

.mature{
    color: red;
}
.post div{
	display: flex;
	word-wrap: break-word; /* IE 5+ */
}

.post .info{
	flex-direction: column;
}

.post .post_info, .links{
	flex-direction: row;
    flex-wrap: wrap;
}

.post .content{
	display: block;
}

.info {
	height: fit-content;
}

.one-column {
    margin: auto;
    max-width: 100%;
    display: flex;
    flex-direction: column;
  }

@media only screen and (min-width: 768px) {
    .one-column {
        min-width: 375px;
        margin: auto;
        max-width: 50%;
        display: flex;
        flex-direction: column;
      }
}
