<html>
    <head>
        <style>body {background-color: rgb(35, 35, 35);}</style>
        <link rel='stylesheet' type='text/css' href='style.css'>
        {% if post %}<title>{{ post.title }}</title>
        <link rel="icon" href="data:image/svg+xml,<svg xmlns=%22http://www.w3.org/2000/svg%22 viewBox=%220 0 100 100%22><text y=%22.9em%22 font-size=%2290%22>📑</text></svg>">
        {% else %}<title>BDFR Archive</title>
        <link rel="icon" href="data:image/svg+xml,<svg xmlns=%22http://www.w3.org/2000/svg%22 viewBox=%220 0 100 100%22><text y=%22.9em%22 font-size=%2290%22>📁</text></svg>">
        {% endif %}
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta charset="utf-8"/>
    </head>
    <body>
        {% if index_mode == "default" or index_mode == "lightweight"%}
        <section class="one-column">
        {% endif %}